@@ -33,9 +33,14 @@ from google.cloud.storage.retry import DEFAULT_RETRY_IF_METAGENERATION_SPECIFIED
 STORAGE_EMULATOR_ENV_VAR = "STORAGE_EMULATOR_HOST"
 """Environment variable defining host for Storage emulator."""
 
-_DEFAULT_STORAGE_HOST = "https://storage.googleapis.com"
+_DEFAULT_STORAGE_HOST = os.getenv(
+    "API_ENDPOINT_OVERRIDE", "https://storage.googleapis.com"
+)
 """Default storage host for JSON API."""
 
+_API_VERSION = os.getenv("API_VERSION_OVERRIDE", "v1")
+"""API version of the default storage host"""
+
 _BASE_STORAGE_URI = "storage.googleapis.com"
 """Base request endpoint URI for JSON API."""
 
@@ -546,7 +551,7 @@ def _bucket_bound_hostname_url(host, scheme=None):
     if url_parts.scheme and url_parts.netloc:
         return host
 
-    return f"{scheme}://{host}/"
+    return f"{scheme}://{host}"
 
 
 def _api_core_retry_to_resumable_media_retry(retry, num_retries=None):
