@@ -23,7 +23,7 @@ from email.parser import Parser
 import io
 import json
 
-import requests  # type: ignore
+import requests
 
 from google.cloud import _helpers
 from google.cloud import exceptions
@@ -57,10 +57,8 @@ class MIMEApplicationHTTP(MIMEApplication):
             headers["Content-Length"] = len(body)
         if body is None:
             body = ""
-        lines = ["%s %s HTTP/1.1" % (method, uri)]
-        lines.extend(
-            ["%s: %s" % (key, value) for key, value in sorted(headers.items())]
-        )
+        lines = [f"{method} {uri} HTTP/1.1"]
+        lines.extend([f"{key}: {value}" for key, value in sorted(headers.items())])
         lines.append("")
         lines.append(body)
         payload = "\r\n".join(lines)
@@ -86,7 +84,7 @@ class _FutureDict(object):
         :raises: :class:`KeyError` always since the future is intended to fail
                  as a dictionary.
         """
-        raise KeyError("Cannot get(%r, default=%r) on a future" % (key, default))
+        raise KeyError(f"Cannot get({key!r}, default={default!r}) on a future")
 
     def __getitem__(self, key):
         """Stand-in for dict[key].
@@ -97,7 +95,7 @@ class _FutureDict(object):
         :raises: :class:`KeyError` always since the future is intended to fail
                  as a dictionary.
         """
-        raise KeyError("Cannot get item %r from a future" % (key,))
+        raise KeyError(f"Cannot get item {key!r} from a future")
 
     def __setitem__(self, key, value):
         """Stand-in for dict[key] = value.
@@ -111,7 +109,7 @@ class _FutureDict(object):
         :raises: :class:`KeyError` always since the future is intended to fail
                  as a dictionary.
         """
-        raise KeyError("Cannot set %r -> %r on a future" % (key, value))
+        raise KeyError(f"Cannot set {key!r} -> {value!r} on a future")
 
 
 class _FutureResponse(requests.Response):
@@ -257,7 +255,7 @@ class Batch(Connection):
         """
         headers, body, timeout = self._prepare_batch_request()
 
-        url = "%s/batch/storage/v1" % self.API_BASE_URL
+        url = f"{self.API_BASE_URL}/batch/storage/v1"
 
         # Use the private ``_base_connection`` rather than the property
         # ``_connection``, since the property may be this
@@ -332,7 +330,7 @@ def _unpack_batch_response(response):
 
         subresponse = requests.Response()
         subresponse.request = requests.Request(
-            method="BATCH", url="contentid://{}".format(content_id)
+            method="BATCH", url=f"contentid://{content_id}"
         ).prepare()
         subresponse.status_code = int(status)
         subresponse.headers.update(msg_headers)
