@@ -12,6 +12,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""Support for file-like I/O."""
+
 import io
 import warnings
 
@@ -106,7 +108,7 @@ class BlobReader(io.BufferedIOBase):
         for kwarg in download_kwargs:
             if kwarg not in VALID_DOWNLOAD_KWARGS:
                 raise ValueError(
-                    "BlobReader does not support keyword argument {}.".format(kwarg)
+                    f"BlobReader does not support keyword argument {kwarg}."
                 )
 
         self._blob = blob
@@ -144,7 +146,7 @@ class BlobReader(io.BufferedIOBase):
                     end=fetch_end,
                     checksum=None,
                     retry=self._retry,
-                    **self._download_kwargs
+                    **self._download_kwargs,
                 )
             except RequestRangeNotSatisfiable:
                 # We've reached the end of the file. Python file objects should
@@ -299,12 +301,12 @@ class BlobWriter(io.BufferedIOBase):
         text_mode=False,
         ignore_flush=False,
         retry=DEFAULT_RETRY_IF_GENERATION_SPECIFIED,
-        **upload_kwargs
+        **upload_kwargs,
     ):
         for kwarg in upload_kwargs:
             if kwarg not in VALID_UPLOAD_KWARGS:
                 raise ValueError(
-                    "BlobWriter does not support keyword argument {}.".format(kwarg)
+                    f"BlobWriter does not support keyword argument {kwarg}."
                 )
         self._blob = blob
         self._buffer = SlidingBuffer()
@@ -390,7 +392,7 @@ class BlobWriter(io.BufferedIOBase):
             num_retries,
             chunk_size=self._chunk_size,
             retry=retry,
-            **self._upload_kwargs
+            **self._upload_kwargs,
         )
 
     def _upload_chunks_from_buffer(self, num_chunks):
@@ -423,9 +425,8 @@ class BlobWriter(io.BufferedIOBase):
             )
 
     def close(self):
-        self._checkClosed()  # Raises ValueError if closed.
-
-        self._upload_chunks_from_buffer(1)
+        if not self._buffer.closed:
+            self._upload_chunks_from_buffer(1)
         self._buffer.close()
 
     def _checkClosed(self):
