@@ -13,7 +13,6 @@
 # limitations under the License.
 
 import datetime
-
 import pytest
 
 from google.api_core import exceptions
@@ -124,6 +123,10 @@ def test_bucket_lifecycle_rules(storage_client, buckets_to_delete):
     assert list(bucket.lifecycle_rules) == []
 
 
+@pytest.mark.skipif(
+    _helpers.is_api_endpoint_override,
+    reason="Test does not yet support endpoint override",
+)
 def test_bucket_update_labels(storage_client, buckets_to_delete):
     bucket_name = _helpers.unique_name("update-labels")
     bucket = _helpers.retry_429_503(storage_client.create_bucket)(bucket_name)
@@ -632,6 +635,10 @@ def test_bucket_w_retention_period(
     bucket.default_event_based_hold = False
     bucket.patch()
 
+    # Changes to the bucket will be readable immediately after writing,
+    # but configuration changes may take time to propagate.
+    _helpers.retry_has_retention_period(bucket.reload)()
+
     assert bucket.retention_period == period_secs
     assert isinstance(bucket.retention_policy_effective_time, datetime.datetime)
     assert not bucket.default_event_based_hold
@@ -645,6 +652,7 @@ def test_bucket_w_retention_period(
     blobs_to_delete.append(blob)
 
     other = bucket.get_blob(blob_name)
+    _helpers.retry_has_retention_expiration(other.reload)()
 
     assert not other.event_based_hold
     assert not other.temporary_hold
@@ -656,12 +664,16 @@ def test_bucket_w_retention_period(
     bucket.retention_period = None
     bucket.patch()
 
+    # Changes to the bucket will be readable immediately after writing,
+    # but configuration changes may take time to propagate.
+    _helpers.retry_no_retention_period(bucket.reload)()
+
     assert bucket.retention_period is None
     assert bucket.retention_policy_effective_time is None
     assert not bucket.default_event_based_hold
     assert not bucket.retention_policy_locked
 
-    _helpers.retry_no_event_based_hold(other.reload)()
+    _helpers.retry_no_retention_expiration(other.reload)()
 
     assert not other.event_based_hold
     assert not other.temporary_hold
@@ -673,16 +685,10 @@ def test_bucket_w_retention_period(
 
 def test_bucket_w_default_event_based_hold(
     storage_client,
-    buckets_to_delete,
     blobs_to_delete,
+    default_ebh_bucket,
 ):
-    bucket_name = _helpers.unique_name("w-def-ebh")
-    bucket = _helpers.retry_429_503(storage_client.create_bucket)(bucket_name)
-    buckets_to_delete.append(bucket)
-
-    bucket.default_event_based_hold = True
-    bucket.patch()
-
+    bucket = storage_client.get_bucket(default_ebh_bucket)
     assert bucket.default_event_based_hold
     assert bucket.retention_period is None
     assert bucket.retention_policy_effective_time is None
@@ -716,11 +722,14 @@ def test_bucket_w_default_event_based_hold(
     assert bucket.retention_policy_effective_time is None
     assert not bucket.retention_policy_locked
 
+    # Changes to the bucket will be readable immediately after writing,
+    # but configuration changes may take time to propagate.
+    _helpers.await_config_changes_propagate()
+
     blob.upload_from_string(payload)
 
     # https://github.com/googleapis/python-storage/issues/435
-    if blob.event_based_hold:
-        _helpers.retry_no_event_based_hold(blob.reload)()
+    _helpers.retry_no_event_based_hold(blob.reload)()
 
     assert not blob.event_based_hold
     assert not blob.temporary_hold
@@ -791,6 +800,10 @@ def test_bucket_lock_retention_policy(
         bucket.patch()
 
 
+@pytest.mark.skipif(
+    _helpers.is_api_endpoint_override,
+    reason="Test does not yet support endpoint override",
+)
 def test_new_bucket_w_ubla(
     storage_client,
     buckets_to_delete,
@@ -862,6 +875,7 @@ def test_ubla_set_unset_preserves_acls(
     # Clear UBLA
     bucket.iam_configuration.uniform_bucket_level_access_enabled = False
     bucket.patch()
+    _helpers.await_config_changes_propagate()
 
     # Query ACLs after clearing UBLA
     bucket.acl.reload()
@@ -959,6 +973,10 @@ def test_new_bucket_created_w_enforced_pap(
     assert not bucket.iam_configuration.uniform_bucket_level_access_enabled
 
 
+@pytest.mark.skipif(
+    _helpers.is_api_endpoint_override,
+    reason="Test does not yet support endpoint override",
+)
 def test_new_bucket_with_rpo(
     storage_client,
     buckets_to_delete,
@@ -978,3 +996,25 @@ def test_new_bucket_with_rpo(
     bucket_from_server = storage_client.get_bucket(bucket_name)
 
     assert bucket_from_server.rpo == constants.RPO_ASYNC_TURBO
+
+
+def test_new_bucket_with_autoclass(
+    storage_client,
+    buckets_to_delete,
+):
+    # Autoclass can be enabled/disabled via bucket create
+    bucket_name = _helpers.unique_name("new-w-autoclass")
+    bucket_obj = storage_client.bucket(bucket_name)
+    bucket_obj.autoclass_enabled = True
+    bucket = storage_client.create_bucket(bucket_obj)
+    previous_toggle_time = bucket.autoclass_toggle_time
+    buckets_to_delete.append(bucket)
+
+    assert bucket.autoclass_enabled is True
+
+    # Autoclass can be enabled/disabled via bucket patch
+    bucket.autoclass_enabled = False
+    bucket.patch()
+
+    assert bucket.autoclass_enabled is False
+    assert bucket.autoclass_toggle_time != previous_toggle_time
